"""SPF records updater"""
import logging

from ee_spf_flattener.config import config

LOG = logging.getLogger(__name__)


class BaseUpdater:
    """Base class to implement an SPF record updater"""

    def initialize(self):
        """Initialize updater"""

    @property
    def record_name_format(self):
        """Retrieve configured SPF records name format"""
        return config.get("flattening.spf_record_name_format", required=True)

    def get_record_name(self, idx):
        """Compute and retrieve SPF record name"""
        return self.record_name_format.format(idx if idx else "")

    @staticmethod
    def get_records_domain(records):
        """Compute the domain name from the first SPF record name"""
        domain = ".".join(next(iter(records)).split(".")[1:])
        LOG.debug("Detected domain: %s", domain)
        return domain

    def update_spf_records(self, records):
        """Update SPF records"""
        raise NotImplementedError()
